@@ -57,6 +57,5 @@ def main():
 
 
 if __name__ == "__main__":
-    parser = get_parser()
-    parser.parse_args()
+    get_parser().parse_args()
     main()
